OC.L10N.register(
    "files",
    {
    "File could not be found" : "لم يتم العثور على الملف",
    "Move or copy" : "أنقل أو انسخ",
    "Download" : "تنزيل",
    "Delete" : "حذف ",
    "Tags" : "الوسوم",
    "Show list view" : "اظهر معاينات الروابط",
    "Show grid view" : "أعرض شبكياً",
    "Home" : "الرئيسية",
    "Close" : "إغلاق",
    "Could not create folder \"{dir}\"" : "لا يمكن إنشاء المجلد \"{dir}\"",
    "This will stop your current uploads." : "هذا سيقوم بوقف رفع الملفات الحالية.",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات.",
    "Processing files …" : "معالجة الملفات…",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، إنك بصدد رفع {size1} ولكن المساحة المتبقية المتوفرة تبلُغ {size2}",
    "Target folder \"{dir}\" does not exist any more" : "المجلد المطلوب \"{dir}\" غير موجود بعد الان",
    "Not enough free space" : "لا يوجد مساحة تخزينية كافية",
    "An unknown error has occurred" : "حدث خطأ غير معروف",
    "File could not be uploaded" : "لا يمكن تحميل الملف ",
    "Uploading …" : "جاري الرفع...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "التحديث جارٍ … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} من {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "رفع هذا النوع الملفات غير مدعوم",
    "Target folder does not exist any more" : "المجلد المراد غير موجود بعد الان",
    "Operation is blocked by access control" : "العمليات حظرت الوصول لهذه الخدمة",
    "Error when assembling chunks, status code {status}" : "خطأ عند تجميع القطع، حالة الخطأ {status}",
    "Actions" : "الإجراءات",
    "Rename" : "إعادة التسمية",
    "Move" : "نقل",
    "Copy" : "نسخ",
    "Choose target folder" : "اختر مكان المجلد",
    "Set reminder" : "ضبط التذكير",
    "Edit locally" : "تعديل محليًا",
    "Open" : "افتح",
    "Delete file" : "إحذِف الملف",
    "Delete folder" : "حذف مجلد واحد",
    "Disconnect storage" : "قطع اتصال التخزين",
    "Leave this share" : "مغادرة هذه المشاركة",
    "Could not load info for file \"{file}\"" : "لم يستطع تحميل معلومات الملف \"{file}\"",
    "Files" : "الملفات",
    "Details" : "التفاصيل",
    "Please select tag(s) to add to the selection" : "يرجى تحديد علامة (علامات) لإضافتها إلى التحديد",
    "Apply tag(s) to selection" : "تطبيق العلامة (العلامات) على التحديد",
    "Select directory \"{dirName}\"" : "حدد المجلد \"{اسم المجلد}\"",
    "Select file \"{fileName}\"" : "حدد الملف \"{اسم الملف}\"",
    "Pending" : "قيد الانتظار",
    "Unable to determine date" : "تعذر تحديد التاريخ",
    "This operation is forbidden" : "هذة العملية ممنوعة ",
    "This directory is unavailable, please check the logs or contact the administrator" : "هذا المجلد غير متوفر، الرجاء مراجعة سجل الأخطاء أو الاتصال بمدير النظام",
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
    "Could not move \"{file}\", target exists" : "لا يمكن نقل  \"{file}\", الملف موجود بالفعل هناك",
    "Could not move \"{file}\"" : "لا يمكن نقل \"{file}\"",
    "copy" : "أنسخ",
    "Could not copy \"{file}\", target exists" : "لم يستطع نسخ \"{file}\"، المستهدف موجود",
    "Could not copy \"{file}\"" : "لم يستطع نسخ \"{file}\"",
    "Copied {origin} inside {destination}" : "منسوخ {origin} داخل {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "منسوخ {origin} و {nbfiles} ملفات اخرى داخل {destination}",
    "Failed to redirect to client" : "فشل في التحويل الى العميل",
    "{newName} already exists" : "{newName} موجود مسبقاً",
    "Could not rename \"{fileName}\", it does not exist any more" : "لا يمكن اعادة تسمية \"{fileName}\", لأنه لم يعد موجود",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{targetName}\" مستخدم من قبل في المجلد \"{dir}\". الرجاء اختيار اسم اخر.",
    "Could not rename \"{fileName}\"" : "إعادة تسمية الملف \"{fileName}\" لم تنجح",
    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "لا يمكن إنشاء الملف \"{file}\" فهو موجود بالفعل",
    "Could not create folder \"{dir}\" because it already exists" : "لا يمكن إنشاء المجلد \"{dir}\" فهو موجود بالفعل",
    "Could not fetch file details \"{file}\"" : "لم يتم الوصول إلى معلومات \"{file}\"",
    "Error deleting file \"{fileName}\"." : "خطأ أثناء حذف الملف \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "لا نتائج بحث في مجلدات اخرى ل {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "ادخل حرفين على الاقل للبحث في المجلدات",
    "Name" : "الإسم",
    "Size" : "الحجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا توجد مجلدات","%n مجلد","مجلدان","%n مجلدات","%n مجلد","%n مجلدات"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","%n ملف","ملفان","%n ملفات","%n ملفات","%n ملفات"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "_including %n hidden_::_including %n hidden_" : ["يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي"],
    "You do not have permission to upload or create files here" : "لا يوجد تخويل برفع أو إنشاء ملفات هنا",
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","جاري رفع الملفات %n"],
    "New" : "جديد",
    "New file/folder menu" : "قائمة مجلد/ملف جديد",
    "Select file range" : "حدد نطاق الملف",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} من {quota} مستخدم",
    "{used} used" : "{used} مستخدم",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "\"/\" is not allowed inside a file name." : "\"/\" غير مسموح في تسمية الملف",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" أنه نوع ملف غير مسموح",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "سعة تخزين {owner} المالك ممتلئة ، ولا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "مجلد المجموعة \"{mountPoint}\" ممتلئ ، لا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "وحدة التخزين الخارجية \"{mountPoint}\" ممتلئة ، لا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "Your storage is full, files cannot be updated or synced anymore!" : "سعتك التخزينية ممتلئة ، لا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "تخزين {owner} شبه ممتلئ ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "مجلد مجموعة \"{mountPoint}\" شبه ممتلئ ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "التخزين الخارجي \"{mountPoint}\" شبه ممتلئ ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "مساحة التخزين الخاصة بك شبه ممتلئة ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["تطابق \"{filter}\"","تطابق  \"{filter}\" ","تطابقان \"{filter}\"","تطابقات \"{filter}\"","تطابقات \"{filter}\"","تطابق \"{filter}\""],
    "View in folder" : "اعرض في المجلد",
    "Direct link was copied (only works for people who have access to this file/folder)" : "تم نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
    "Path" : "المسار",
    "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%n بايت"],
    "Favorited" : "المفضلة",
    "Favorite" : "المفضلة",
    "Copy direct link (only works for people who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
    "New folder" : "مجلد جديد",
    "Create new folder" : "إنشاء مجلدا جديد",
    "Upload file" : "رفع ملف",
    "Recent" : "الحديثة",
    "Not favorited" : "ازالة من المفضلة",
    "Remove from favorites" : "إزالته مِن المفضلة",
    "Add to favorites" : "إضافة إلى المفضلة",
    "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث tags",
    "Added to favorites" : "تمت إضافته إلى المفضلة",
    "Removed from favorites" : "تمت إزالته مِن المفضلة",
    "You added {file} to your favorites" : "أنت اضفت {file} إلى مفضلتك",
    "You removed {file} from your favorites" : "تم ازالت {file} من مفضلتك",
    "Favorites" : "المفضلة ",
    "File changes" : "تغيير في ملف",
    "Created by {user}" : "انشاء جديد من قبل {user}",
    "Changed by {user}" : "تغيير من قبل {user}",
    "Deleted by {user}" : "حذف من قبل {user}",
    "Restored by {user}" : "استعادة من قبل {user}",
    "Renamed by {user}" : "اعادة تسمية من قبل {user}",
    "Moved by {user}" : "نقل من قبل {user}",
    "\"remote account\"" : "\"حساب قصِي remote account\"",
    "You created {file}" : "أنشأتَ {file}",
    "You created an encrypted file in {file}" : "انشأت ملف مشفر في {file}",
    "{user} created {file}" : "{user} انشاء ملف {file}",
    "{user} created an encrypted file in {file}" : "{user} انشاء ملف مشفر {file}",
    "{file} was created in a public folder" : "{file} انشاء ملف في المجلد العام",
    "You changed {file}" : "أنت قمت بتغيير {file}",
    "You changed an encrypted file in {file}" : "أنت قمت بتغيير ملف مشفر {file}",
    "{user} changed {file}" : "{user} تغيير {file}",
    "{user} changed an encrypted file in {file}" : "{user} تغيير ملف مشفر {file}",
    "You deleted {file}" : "أنت حذفت ملف {file}",
    "You deleted an encrypted file in {file}" : "أنت حذفت ملف مشفر {file}",
    "{user} deleted {file}" : "{user} حذف {file}",
    "{user} deleted an encrypted file in {file}" : "{user} حذف ملف مشفر {file}",
    "You restored {file}" : "أنت قمت باستعادة {file}",
    "{user} restored {file}" : "{user} استعادة ملف {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "لقد أعدت تسمية {oldfile} (مخفي) إلى {newfile} (مخفي)",
    "You renamed {oldfile} (hidden) to {newfile}" : "لقد أعدت تسمية {oldfile} (مخفي) إلى {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "لقد أعدت تسمية {oldfile} إلى {newfile} (مخفي)",
    "You renamed {oldfile} to {newfile}" : "أنت أعدت تسمية {oldfile} إلى {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "أعاد {user} تسمية {oldfile} (مخفي) إلى {newfile} (مخفي)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "أعاد {user} تسمية {oldfile} (مخفي) إلى {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "أعاد {user} تسمية {oldfile} إلى {newfile} (مخفي)",
    "{user} renamed {oldfile} to {newfile}" : "{user} اعادة تسمية {oldfile} إلى {newfile}",
    "You moved {oldfile} to {newfile}" : "أنت نقلت {oldfile} إلى {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} نقل {oldfile} إلى {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "ملف اضيف إلى او تم ازالته من <strong> مفضلتك </strong>",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A favorite file or folder has been <strong>changed</strong>" : "ملف في المفضلة تم <strong>تم تغييره</strong>",
    "Failed to authorize" : "فشل في التخويل",
    "Invalid folder path" : "مسار المجلد غير صحيح",
    "Folder not found" : "المجلد غير موجود",
    "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
    "Files compatibility" : "توافقية الملفات",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "السماح بتقييد أسماء الملفات لضمان إمكانية مزامنة الملفات مع جميع العملاء. بشكل افتراضي، يُسمح بجميع أسماء الملفات الصالحة على POSIX (مثل Linux أو macOS).",
    "Enforce Windows compatibility" : "فرض التوافق مع وندوز",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "سيؤدي هذا إلى حظر أسماء الملفات غير الصالحة على أنظمة Windows؛ مثل استخدام الأسماء المحجوزة أو الأحرف الخاصة. لكن هذا لن يفرض توافق حساسية الحالة.",
    "Accept" : "قبول",
    "Reject" : "رفض",
    "Incoming ownership transfer from {user}" : "تم تحويل ملكية الملف إليك من قبل {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "هل تريد الموافقة {path}?\n\nملاحظة: عملية موافقة على النقل قد تستغرق إلى 1 ساعة.",
    "Ownership transfer denied" : "تمّ رفض نقل الملكية",
    "Your ownership transfer of {path} was denied by {user}." : "تمّ رفض نقلك لمِلكيّتك في {path} من قِبَل المستخدِم {user}.",
    "Ownership transfer failed" : "فشل نقل الملكية",
    "Your ownership transfer of {path} to {user} failed." : "فشلت عمليتك لنقل الـ {path} إلى {user}",
    "The ownership transfer of {path} from {user} failed." : "فشل عملية النقل لـ {path} من قبل {user}",
    "Ownership transfer done" : "تم نقل الملكية بنجاح",
    "Your ownership transfer of {path} to {user} has completed." : "عمليتك لنقل الـ {path} إلى {user} تمت بنجاح.",
    "The ownership transfer of {path} from {user} has completed." : "نقل الملكية لـ {path} من قبل {user} تمت بنجاح.",
    "in %s" : "في %s",
    "Transferred from %1$s on %2$s" : "تمّ النقل من %1$s في%2$s",
    "File Management" : "إدارة الملفات",
    "Current directory path" : "مسار المجلد الحالي",
    "Reload current directory" : "إعادة تحميل المجلد الحالي",
    "Go to the \"{dir}\" directory" : "إنتقل إلى المجلد \"{dir}\"",
    "Drag and drop files here to upload" : "إسحَب و أفلِت الملفات هنا لرفعها",
    "Your have used your space quota and cannot upload files anymore" : "لقد استنفذت حصتك التخزينية و لم يعد بإمكانك رفع أي ملفات بعدُ",
    "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" الأمر نُفّذ بنجاح",
    "\"{displayName}\" action failed" : "\"{displayName}\" الأمر أخفق عند التنفيذ",
    "Toggle selection for file \"{displayName}\"" : "تبديل الاختيار للملف \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "تبديل الاختيار للمجلد \"{displayName}\"",
    "File is loading" : "الملف قيد التحميل ...",
    "Folder is loading" : "المجلد قيد التحميل ...",
    "Rename file" : "إعادة تسمية الملف",
    "Filename" : "اسم الملف",
    "Folder name" : "اسم المجلد",
    "This node is unavailable" : "هذه العُقْدَة node غير متوفرة ",
    "Another entry with the same name already exists." : "توجد سلفاً إدخالية أخرى بنفس هذا الاسم.",
    "Invalid filename." : "اسم ملف غير صحيح.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "تمت إعادة تسمية \"{oldName}\" إلى \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{newName}\" مُستعمَلٌ سلفاً في المجلّد\"{dir}\". إختَر اسماً آخر رجاءً.",
    "Could not rename \"{oldName}\"" : "تعذرت إعادة تسمية \"{oldName}\"",
    "Clear filter" : "ازل التصفية",
    "Type" : "حسب النوع",
    "Active filters" : "فلاتر نشطة",
    "Remove filter" : "إزالة الفلتر",
    "Total rows summary" : "ملخص مجموع الأسطر",
    "Toggle selection for all files and folders" : "تبديل الاختيار لكل الملفات و المجلدات",
    "(selected)" : "(تم اختياره)",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" فشل في بعض العناصر",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" حزمة الأوامر نُفّذت بنجاح",
    "{count} selected" : "{count} تمّ تحديدها",
    "List of files and folders." : "قائمة الملفات و المجلدات",
    "Column headers with buttons are sortable." : "ترويسات الأعمدة ذات الأزرار قابلة للترتيب.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "لم يتم عرض هذه القائمة بالكامل لأسباب تتعلق بالأداء. سيتم عرض الملفات تباعاً أثناء التنقل عبر القائمة.",
    "File not found" : "تعذر العثور على الملف",
    "Storage information" : "معلومات التخزين",
    "Storage quota" : "حصة التخزين",
    "{usedQuotaByte} used" : "{usedQuotaByte} مستخدمة",
    "{relative}% used" : "{relative}% مستخدمة",
    "Could not refresh storage stats" : "تعذر تحديث حالة التخزين",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Create" : "إنشاء",
    "This name is already in use." : "هذا الاسم سبق استعماله.",
    "Fill template fields" : "قُم بملء حقول القالب",
    "Submitting fields…" : "إرسال الحقول ...",
    "Submit" : "إرسال ",
    "Transfer ownership of a file or folder" : "تحويل ملكية ملف أو مجلد",
    "Choose file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
    "Change" : "تغير",
    "New owner" : "مالك جديد",
    "Choose a file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
    "Transfer" : "نقل ملكية",
    "Transfer {path} to {userid}" : "نقل ملكية {path} إلى {userid}",
    "Invalid path selected" : "المسار او الملف غير صحيح",
    "Unknown error" : "خطأ غير معروف",
    "Ownership transfer request sent" : "طلب نقل الملكية أرسل بنجاح",
    "Cannot transfer ownership of a file or folder you do not own" : "لايمكنك نقل ملكية ملف أو مجلد لا تملكه",
    "Select file or folder to link to" : "اختر ملف أو مجلد للربط معه",
    "Choose file" : "إختَر ملفاً",
    "Choose {file}" : "إختَر {file}",
    "Loading current folder" : "تحميل المجلد الحالي",
    "No files in here" : "لا يوجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
    "Go to the previous folder" : "إنتقل للمجلد السابق",
    "Go back" : "العودة",
    "Share" : "مُشارَكة",
    "Shared by link" : "شاركته باستخدام رابط مشاركة",
    "Shared" : "مُشارَكة",
    "Switch to list view" : "التبديل إلى عرض القائمة",
    "Switch to grid view" : "بدِّل إلى المنظور الصندوقي",
    "Upload was cancelled by user" : "عملية الرفع تمّ إلغاؤها من مُستخدِم",
    "Error during upload: {message}" : "حدث خطأ أثناء الرفع: {message}",
    "Error during upload, status code {status}" : "حدث خطأ أثناء الرفع. رمز الحالة {status}",
    "Unknown error during upload" : "خطأ غير محدد حدث أثناء الرفع",
    "Filter filenames…" : "فلترة أسماء الملفات ...",
    "Views" : "مشاهدات",
    "Files settings" : "إعدادات الملفات",
    "File cannot be accessed" : "الملف لم يمكن الوصول إليه",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "إمّا أن الملف غير موجود أو أنك لا تمتلك الصلاحية لعرضه. أُطلُب من المُرسل أن يتشاركه معك.",
    "Your files" : "ملفاتك",
    "Open in files" : "إفتَح في شاشة الملفات",
    "Sort favorites first" : "فرز المفضلات أولا",
    "Sort folders before files" : "فرز المجلدات قبل الملفات",
    "Show hidden files" : "عرض الملفات المخفية",
    "Crop image previews" : "اقتصاص صورة العروض",
    "Enable the grid view" : "تمكين المنظور الصندوقي",
    "Enable folder tree" : "تمكين شجرة المجلدات",
    "Additional settings" : "الإعدادات المتقدمة",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "عنوان URL لـ WebDAV",
    "Copy to clipboard" : "نسخ الرابط",
    "Use this address to access your Files via WebDAV" : "استخدم هذا العنوان للوصول للملفات عبر WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "إذا كنت قد فعّلت خاصية \"التحقق بأكثل من عامل\" 2FA، يجب عليك تجديد كلمة سر التطبيق بالضغط هنا.",
    "Clipboard is not available" : "الحافظة غير متاحة",
    "WebDAV URL copied to clipboard" : "تم نسخ WebDAV URL إلى الحافظة",
    "Unable to change the favourite state of the file" : "لم نستطع تغير الحالة المفضلة للملف",
    "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
    "Pick a template for {name}" : "اختر قالبا لـ {name}",
    "Create a new file with the selected template" : "إنشاء ملف جديد بإستخدام القالب المحدد",
    "Creating file" : "إنشاء ملف",
    "Blank" : "فارغ",
    "Unable to create new file from template" : "تعذر إنشاء الملف الجديد من القالب",
    "Deletion cancelled" : "تمّ إلغاء الحذف",
    "Delete permanently" : "حذف بشكل دائم",
    "Delete and unshare" : "إحذِف و الغٍ المشاركات ",
    "Leave these shares" : "مغادرة هاتين المشاركتين",
    "Disconnect storages" : "فصل وحدات تخزين",
    "Delete files" : "حذف الملفات",
    "Delete folders" : "حذف مجلدين",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عنصراً","أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك أن تحذف نهائياً {count} عنصراً"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عنصراً"],
    "Confirm deletion" : "أكِّد على الحذف",
    "Cancel" : "الغاء",
    "Edit file locally" : "تحرير الملف محليّاً",
    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "يُفترض أن يفتح الملف الآن محليّاً. إذا لم يكن الأمر كذلك، تأكد من تنصيب تطبيق العميل desktop client على سطح المكتب عندك.",
    "Retry local edit" : "إعادة محاولة التحرير محليّاً",
    "Edit online" : "التحرير عبر الإنترنت",
    "Destination is not a folder" : "المَقصَد ليس مُجلّداً",
    "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
    "(copy)" : "(نسخ)",
    "(copy %n)" : "(نسخ %n)",
    "Move cancelled" : "تمّ إلغاء النقل",
    "A file or folder with that name already exists in this folder" : "ملف أو مجلد بنفس ذاك الاسم موجود سلفاً في هذا المجلد",
    "The files are locked" : "الملفات مقفلة",
    "The file does not exist anymore" : "الملف لم يعد موجوداً",
    "Choose destination" : "إختَر المَقصِد",
    "Copy to {target}" : "أُنسُخ إلى {target}",
    "Move to {target}" : "أُنقُل إلى {target}",
    "Move or copy operation failed" : "عملية النسخ أو النقل أخفقت",
    "Cancelled move or copy of \"{filename}\"." : "تمّ إلغاء عملية حذف أو نقل الملف \"{filename}\".",
    "Cancelled move or copy operation" : ".عملية النسخ أو النقل تمّ إلغاؤها",
    "Open folder {displayName}" : "إفتح المجلد {displayName}",
    "Open in Files" : "إفتَح في \"الملفات\"",
    "Open details" : "افتح التفاصيل",
    "Today" : "اليوم",
    "Last 7 days" : "آخر 7 أيام",
    "Last 30 days" : "آخر 30 يوماً",
    "This year ({year})" : "هذا العام ({year})",
    "Last year ({year})" : "العام الماضي ({year})",
    "Documents" : "المستندات",
    "Spreadsheets" : "الجداول الالكترونية",
    "Presentations" : "العروض",
    "PDFs" : "ملفات بي دي إف",
    "Folders" : "المجلدات",
    "Audio" : "صوت",
    "Photos and images" : "الصور ",
    "Videos" : "فيديوهات",
    "New folder creation cancelled" : "تمّ إلغاء عملية إنشاء مجلد جديد",
    "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
    "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
    "Create templates folder" : "إنشاء مجلد للقوالب",
    "Templates" : "القوالب",
    "New template folder" : "مجلد القوالب الجديد",
    "In folder" : "في المجلد",
    "Search in folder: {folder}" : "البحث في المجلد:  {folder}",
    "One of the dropped files could not be processed" : "أحد الملفات المُفلَتة لا يمكن معالجته",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "مُستعرِضُك لا يدعم واجهة تطبيق نظام الملفات Filesystem API. لذا، لن يُمكن رفع المجلدات",
    "No files to upload" : "لا توجد ملفات لرفعها",
    "Unable to create the directory {directory}" : "تعذّر إنشاء الدليل {directory}",
    "Some files could not be uploaded" : "بعض الملفات لم يمكن رفعها",
    "Files uploaded successfully" : "تمّ رفع الملفات بنجاحٍ",
    "No files to process" : "لا توجد ملفات لمعالجتها",
    "Some files could not be copied" : "بعض الملفات لا يمكن نسخها",
    "Some files could not be moved" : "تعذر نقل بعض الملفات",
    "Files copied successfully" : "تمّ نسخ الملفات بنجاحٍ",
    "Files moved successfully" : "تمّ نقل الملفات بنجاحٍ",
    "Conflicts resolution skipped" : "تمّ تخطّي حلّ التعارضات",
    "Upload cancelled" : "تمّ إلغاء الرفع",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} مجلد","{folderCount} مجلد","{folderCount} مجلدان","{folderCount} مجلد","{folderCount} مجلدات","{folderCount} مجلدات"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ملف","{fileCount} ملف","{fileCount} ملفان","{fileCount} ملف","{fileCount} ملفات","{fileCount} ملفات"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلدان","ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلدات","ملف واحد 1 و {folderCount} مجلدات"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ملف و مجلد واحد 1","{fileCount} ملف و مجلد واحد 1","{fileCount} ملفان و مجلد واحد 1","{fileCount} ملف و مجلد واحد 1","{fileCount} ملفات و مجلد واحد 1","{fileCount} ملفات و مجلد واحد 1"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} ملف و {folderCount} مجلد",
    "Filename must not be empty." : "يجب ألّا يكون اسم الملف فارغاً.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" غير مسموح به في اسم الملف.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" هو اسم محجوز و لا يجوز استعماله كاسم لملف.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" غير مسموح به كنوع لملف.",
    "Filenames must not end with \"{extension}\"." : "أسماء الملفات يجب ألّا تنتهي بـ \"{extension}\".",
    "List of favorites files and folders." : "قائمة الملفات والمجلدات المفضلة.",
    "No favorites yet" : "ليست عندك مفضلات بعد",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
    "All files" : "كل الملفات",
    "List of your files and folders." : "قائمة بملفاتك و مجلداتك",
    "All folders" : "كل المجلدات",
    "Personal Files" : "ملفات شخصية",
    "List of your files and folders that are not shared." : "قائمة بالملفات و المجلدات التي لم تتم مشاركتها.",
    "No personal files found" : "لا توجد أي ملفات شخصية",
    "Files that are not shared will show up here." : "الملفات التي لم تتم مشاركتها ستُعرض هنا",
    "List of recently modified files and folders." : "قائمة بالملفات و المجلدات التي تمّ تعديلها مؤخراً.",
    "No recently modified files" : "لا توجد أيّ ملفات تمّ تعديلها مؤخراً",
    "Files and folders you recently modified will show up here." : "الملفات و المجلدات التي تمّ تعديلها مؤخراً ستظهر هنا.",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "Text file" : "ملف نصي",
    "New text file.txt" : "ملف نصي جديد fille.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "تم نسخ الرابط المباشر (تعمل فقط بالنسبة للمستخدمين الذين يملكون تخويلاً بالوصول إلى هذا الملف أو المجلد)",
    "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للمستخدمين الذين يمكنهم الوصول الى هذا الملف/المجلد)",
    "\"remote user\"" : "\"مستخدم عن بعد\"",
    "{newName} already exists." : "{newName} موجود بالفعل.",
    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" غير مقبولة في اسم الملف.",
    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" محظور استعماله كاسم لملف أو مجلد.",
    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" غير مقبول كنوع لملف.",
    "Filenames must not end with \"{segment}\"." : "أسماء الملفات يجب ألّا تنتهي بـ \"{segment}\".",
    "Name cannot be empty" : "لا يمكن أن يكون الاسم فارغاً",
    "Another entry with the same name already exists" : "إدخال آخر بنفس الاسم موجود بالفعل",
    "Storage informations" : "معلومات التخزين",
    "Open the files app settings" : "إفتح إعدادات تطبيق الملفات",
    "You might not have have permissions to view it, ask the sender to share it" : "يمكن ألاّ تكون لديك صلاحية لعرضه، أطلب من المُرسل إن يشاركه معك",
    "The files is locked" : "الملفات مقفله",
    "Create new templates folder" : "إنشيْ مجلد جديد للقوالب",
    "Toggle %1$s sublist" : "تبديل %1$s قائمة فرعية"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
